parade.error package
====================

Submodules
----------

parade.error.flow\_errors module
--------------------------------

.. automodule:: parade.error.flow_errors
    :members:
    :undoc-members:
    :show-inheritance:

parade.error.task\_errors module
--------------------------------

.. automodule:: parade.error.task_errors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.error
    :members:
    :undoc-members:
    :show-inheritance:
